Welcome to ClientVPS Mirrors

Help for package TSANN
Type: Package
Title: Time Series Artificial Neural Network
Version: 0.1.0
Author: Md Yeasin [aut, cre], Ranjit Kumar Paul [aut], Dipro Sinha [aut]
Maintainer: Md Yeasin <yeasin.iasri@gmail.com>
Description: The best ANN structure for time series data analysis is a demanding need in the present era. This package will find the best-fitted ANN model based on forecasting accuracy. The optimum size of the hidden layers was also determined after determining the number of lags to be included. This package has been developed using the algorithm of Paul and Garai (2021) <doi:10.1007/s00500-021-06087-4>.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.1.2
Imports: forecast, gtools, stats, utils
NeedsCompilation: no
Packaged: 2021-12-13 05:23:14 UTC; yeasi
Repository: CRAN
Date/Publication: 2021-12-14 08:40:07 UTC

Time Series Artificial Neural Network

Description

The best ANN structure for time series data analysis is a demanding need in the present era. This package will find the best-fitted ANN model based on forecasting accuracy. The optimum size of the hidden layers was also determined after determining the number of lags to be included. This package has been developed using the algorithm of Paul and Garai (2021) <doi:10.1007/s00500-021-06087-4>.

Usage

Auto.TSANN(data, min.size, max.size, split.ratio)

Arguments

data

Time Series Data

min.size

Minimum Size of Hidden Layer

max.size

Maximum Size of Hidden Layer

split.ratio

Training and Testing Split Ratio

Value

A list containing:

References

Paul, R.K. and Garai, S. (2021). Performance comparison of wavelets-based machine learning technique for forecasting agricultural commodity prices, Soft Computing, 25(20), 12857-12873

Examples

set.seed(16)
x<-rnorm(n = 50, mean = 150, sd = 10)
Auto.TSANN(x,1,2,0.80)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.